[Libreoffice-commits] .: bean/com bean/test cppuhelper/source desktop/source embeddedobj/qa extensions/source filter/qa framework/qa javaunohelper/com jurt/workbench odk/examples package/qa qadevOOo/runner reportdesign/qa sal/osl scp2/source sc/qa scripting/java scripting/source sysui/desktop toolkit/qa toolkit/test vcl/qa writerfilter/qa xmlsecurity/tools

Andras Timar timar at kemper.freedesktop.org
Wed Jan 11 10:25:28 PST 2012


 bean/com/sun/star/beans/LocalOfficeConnection.java                        |    8 +-
 bean/com/sun/star/comp/beans/LocalOfficeConnection.java                   |   12 +--
 bean/com/sun/star/comp/beans/OOoBean.java                                 |    4 -
 bean/test/makefile.mk                                                     |    2 
 cppuhelper/source/bootstrap.cxx                                           |   12 +--
 desktop/source/app/app.cxx                                                |    6 -
 desktop/source/app/officeipcthread.cxx                                    |    4 -
 desktop/source/pkgchk/unopkg/unopkg_misc.cxx                              |   12 +--
 embeddedobj/qa/embedding/makefile.mk                                      |    2 
 extensions/source/nsplugin/source/so_main.cxx                             |    8 +-
 filter/qa/complex/filter/detection/typeDetection/makefile.mk              |    2 
 framework/qa/complex/api_internal/CheckAPI.props                          |    2 
 framework/qa/complex/framework/recovery/RecoveryTest.java                 |    4 -
 framework/qa/complex/framework/recovery/RecoveryTools.java                |   11 +--
 javaunohelper/com/sun/star/comp/helper/Bootstrap.java                     |   12 +--
 jurt/workbench/com/sun/star/comp/urlresolver/UrlResolver_Test.java        |    2 
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Install.txt     |    2 
 odk/examples/DevelopersGuide/ProfUNO/CppBinding/Makefile                  |    2 
 odk/examples/DevelopersGuide/ProfUNO/InterprocessConn/Makefile            |    2 
 odk/examples/cpp/DocumentLoader/Makefile                                  |    2 
 odk/examples/examples.html                                                |    2 
 package/qa/ofopxmlstorages/makefile.mk                                    |    2 
 package/qa/storages/makefile.mk                                           |    2 
 qadevOOo/runner/graphical/JPEGComparator.java                             |    2 
 qadevOOo/runner/graphical/JPEGCreator.java                                |    4 -
 qadevOOo/runner/graphical/PostscriptCreator.java                          |    4 -
 qadevOOo/runner/helper/OfficeProvider.java                                |    4 -
 qadevOOo/runner/util/utils.java                                           |   12 +--
 reportdesign/qa/complex/reportdesign/runner.props                         |    4 -
 sal/osl/unx/signal.c                                                      |    4 -
 sal/osl/w32/signal.cxx                                                    |    4 -
 sc/qa/complex/calcPreview/makefile.mk                                     |    2 
 scp2/source/calc/registryitem_calc.scp                                    |    4 -
 scp2/source/draw/registryitem_draw.scp                                    |    4 -
 scp2/source/impress/registryitem_impress.scp                              |    4 -
 scp2/source/math/registryitem_math.scp                                    |    6 -
 scp2/source/ooo/registryitem_ooo.scp                                      |    2 
 scp2/source/writer/registryitem_writer.scp                                |    4 -
 scripting/java/org/openoffice/idesupport/localoffice/LocalOfficeImpl.java |    2 
 scripting/source/pyprov/msgbox.py                                         |    4 -
 scripting/source/pyprov/officehelper.py                                   |    4 -
 sysui/desktop/man/libreoffice.1                                           |   34 +++++-----
 toolkit/qa/complex/toolkit/UnitConversion.java                            |    2 
 toolkit/test/accessibility/OfficeConnection.java                          |   16 ++--
 vcl/qa/complex/memCheck/makefile.mk                                       |    2 
 writerfilter/qa/complex/ooxml/makefile.mk                                 |    2 
 xmlsecurity/tools/examples/evaluate_win.bat                               |    8 +-
 xmlsecurity/tools/examples/uno_win.bat                                    |    4 -
 48 files changed, 129 insertions(+), 130 deletions(-)

New commits:
commit aab14cb9fbc7d82b804a89e4cc61fb874c8636c8
Author: Andras Timar <atimar at suse.com>
Date:   Wed Jan 11 19:21:33 2012 +0100

    fix prefix of command line switches (-- instead of -)

diff --git a/bean/com/sun/star/beans/LocalOfficeConnection.java b/bean/com/sun/star/beans/LocalOfficeConnection.java
index fc098c3..443941c 100644
--- a/bean/com/sun/star/beans/LocalOfficeConnection.java
+++ b/bean/com/sun/star/beans/LocalOfficeConnection.java
@@ -588,13 +588,13 @@ public class LocalOfficeConnection
            // create call with arguments
             String[] cmdArray = new String[4];
             cmdArray[0] = (new File(getProgramPath(), OFFICE_APP_NAME)).getPath();
-            cmdArray[1] = "-nologo";
-            cmdArray[2] = "-nodefault";
+            cmdArray[1] = "--nologo";
+            cmdArray[2] = "--nodefault";
             if ( mConnType.equals( "pipe" ) )
-                cmdArray[3] = "-accept=pipe,name=" + getIdentifier() + ";" +
+                cmdArray[3] = "--accept=pipe,name=" + getIdentifier() + ";" +
                           mProtocol + ";" + mInitialObject;
             else if ( mConnType.equals( "socket" ) )
-                cmdArray[3] = "-accept=socket,port=" + mPort + ";urp";
+                cmdArray[3] = "--accept=socket,port=" + mPort + ";urp";
             else
                 throw new java.io.IOException( "not connection specified" );
 
diff --git a/bean/com/sun/star/comp/beans/LocalOfficeConnection.java b/bean/com/sun/star/comp/beans/LocalOfficeConnection.java
index cc7545a..bb6abdd 100644
--- a/bean/com/sun/star/comp/beans/LocalOfficeConnection.java
+++ b/bean/com/sun/star/comp/beans/LocalOfficeConnection.java
@@ -747,8 +747,8 @@ public class LocalOfficeConnection
             //examine if user specified command-line options in system properties.
             //We may offer later a more sophisticated way of providing options if
             //the need arises. Currently this is intended to ease the pain during
-            //development  with pre-release builds of OOo where one wants to start
-            //OOo with the -norestore options. The value of the property is simple
+            //development  with pre-release builds of LibO where one wants to start
+            //LibO with the --norestore options. The value of the property is simple
             //passed on to the Runtime.exec call.
             try {
                 sOption = System.getProperty("com.sun.star.officebean.Options");
@@ -768,13 +768,13 @@ public class LocalOfficeConnection
 
 //          cmdArray[0] = (new File(getProgramPath(), OFFICE_APP_NAME)).getPath();
             cmdArray[0] = (new File(unoPath, OFFICE_APP_NAME)).getPath();
-            cmdArray[1] = "-nologo";
-            cmdArray[2] = "-nodefault";
+            cmdArray[1] = "--nologo";
+            cmdArray[2] = "--nodefault";
             if ( mConnType.equals( "pipe" ) )
-                cmdArray[3] = "-accept=pipe,name=" + getIdentifier() + ";" +
+                cmdArray[3] = "--accept=pipe,name=" + getIdentifier() + ";" +
                           mProtocol + ";" + mInitialObject;
             else if ( mConnType.equals( "socket" ) )
-                cmdArray[3] = "-accept=socket,port=" + mPort + ";urp";
+                cmdArray[3] = "--accept=socket,port=" + mPort + ";urp";
             else
                 throw new java.io.IOException( "not connection specified" );
 
diff --git a/bean/com/sun/star/comp/beans/OOoBean.java b/bean/com/sun/star/comp/beans/OOoBean.java
index 3ea15f0..7cba97e 100644
--- a/bean/com/sun/star/comp/beans/OOoBean.java
+++ b/bean/com/sun/star/comp/beans/OOoBean.java
@@ -800,12 +800,12 @@ public class OOoBean
         when at the same time the office writes a backup of the document. This bug
         also affects {@link #storeToByteArray storeToByteArray} and
         {@link #storeToStream storeToStream}. The workaround
-        is to start the office with the option -norestore, which disables the automatic
+        is to start the office with the option --norestore, which disables the automatic
         backup and recovery mechanism. OOoBean offers currently no supported way of providing
         startup options for OOo. But it is possible to set a Java property when starting
         Java, which is examined by OOoBean:
         <pre>
-            java -Dcom.sun.star.officebean.Options=-norestore  ...
+            java -Dcom.sun.star.officebean.Options=--norestore  ...
         </pre>
         It is planned to offer a way of specifying startup options in a future version.
         The property can be used until then. When using this property only one option
diff --git a/bean/test/makefile.mk b/bean/test/makefile.mk
index afc553c..75a7842 100644
--- a/bean/test/makefile.mk
+++ b/bean/test/makefile.mk
@@ -45,7 +45,7 @@ MAXLINELENGTH = 100000
 OFFICE_CLASSPATH_TMP:=$(foreach,i,$(JARFILES) $(office)$/program$/classes$/$(i)$(PATH_SEPERATOR))
 OFFICE_CLASSPATH=$(OFFICE_CLASSPATH_TMP:t"")$(PATH_SEPERATOR)$(CLASSDIR)
 
-OOOBEAN_OPTIONS=-Dcom.sun.star.officebean.Options=-norestore 
+OOOBEAN_OPTIONS=-Dcom.sun.star.officebean.Options=--norestore
 
 
 .INCLUDE: target.mk
diff --git a/cppuhelper/source/bootstrap.cxx b/cppuhelper/source/bootstrap.cxx
index 2fb8ccd..05d404b 100644
--- a/cppuhelper/source/bootstrap.cxx
+++ b/cppuhelper/source/bootstrap.cxx
@@ -567,17 +567,17 @@ Reference< XComponentContext > SAL_CALL bootstrap()
 
         // accept string
         OSL_ASSERT( buf.getLength() == 0 );
-        buf.appendAscii( RTL_CONSTASCII_STRINGPARAM( "-accept=pipe,name=" ) );
+        buf.appendAscii( RTL_CONSTASCII_STRINGPARAM( "--accept=pipe,name=" ) );
         buf.append( sPipeName );
         buf.appendAscii( RTL_CONSTASCII_STRINGPARAM( ";urp;" ) );
 
         // arguments
         OUString args [] = {
-            OUSTR( "-nologo" ),
-            OUSTR( "-nodefault" ),
-            OUSTR( "-norestore" ),
-            OUSTR( "-nocrashreport" ),
-            OUSTR( "-nolockcheck" ),
+            OUSTR( "--nologo" ),
+            OUSTR( "--nodefault" ),
+            OUSTR( "--norestore" ),
+            OUSTR( "--nocrashreport" ),
+            OUSTR( "--nolockcheck" ),
             buf.makeStringAndClear()
         };
         rtl_uString * ar_args [] = {
diff --git a/desktop/source/app/app.cxx b/desktop/source/app/app.cxx
index 855418a..afa53f6 100644
--- a/desktop/source/app/app.cxx
+++ b/desktop/source/app/app.cxx
@@ -1294,7 +1294,7 @@ void restartOnMac(bool passArguments) {
         for (sal_uInt32 i = 0; i < n; ++i) {
             rtl::OUString arg;
             OSL_VERIFY(osl_getCommandArg(i, &arg.pData) == osl_Process_E_None);
-            if (arg.matchAsciiL(RTL_CONSTASCII_STRINGPARAM("-accept="))) {
+            if (arg.matchAsciiL(RTL_CONSTASCII_STRINGPARAM("--accept="))) {
                 wait = true;
             }
             rtl::OString arg8;
@@ -2459,7 +2459,7 @@ void Desktop::OpenClients()
         }
     }
 
-    // Disable AutoSave feature in case "-norestore" or a similare command line switch is set on the command line.
+    // Disable AutoSave feature in case "--norestore" or a similar command line switch is set on the command line.
     // The reason behind: AutoSave/EmergencySave/AutoRecovery share the same data.
     // But the require that all documents, which are saved as backup should exists inside
     // memory. May be this mechanism will be inconsistent if the configuration exists ...
@@ -2894,7 +2894,7 @@ void Desktop::HandleAppEvent( const ApplicationEvent& rAppEvent )
             // connection to the first office. We want to reuse the quickstart option for the first office.
             // NOTICE: The quickstart service must be initialized inside the "main thread", so we use the
             // application events to do this (they are executed inside main thread)!!!
-            // Don't start quickstart service if the user specified "-invisible" on the command line!
+            // Don't start quickstart service if the user specified "--invisible" on the command line!
             sal_Bool bQuickstart( sal_True );
             Sequence< Any > aSeq( 1 );
             aSeq[0] <<= bQuickstart;
diff --git a/desktop/source/app/officeipcthread.cxx b/desktop/source/app/officeipcthread.cxx
index df3306d..4eeb48e 100644
--- a/desktop/source/app/officeipcthread.cxx
+++ b/desktop/source/app/officeipcthread.cxx
@@ -747,7 +747,7 @@ void SAL_CALL OfficeIPCThread::run()
             cProcessed.reset();
             pRequest->pcProcessed = &cProcessed;
 
-            // Print requests are not dependent on the -invisible cmdline argument as they are
+            // Print requests are not dependent on the --invisible cmdline argument as they are
             // loaded with the "hidden" flag! So they are always checked.
             bDocRequestSent |= aCmdLineArgs->GetPrintList( pRequest->aPrintList );
             bDocRequestSent |= ( aCmdLineArgs->GetPrintToList( pRequest->aPrintToList ) &&
@@ -756,7 +756,7 @@ void SAL_CALL OfficeIPCThread::run()
             if ( !rCurrentCmdLineArgs.IsInvisible() )
             {
                 // Read cmdline args that can open/create documents. As they would open a window
-                // they are only allowed if the "-invisible" is currently not used!
+                // they are only allowed if the "--invisible" is currently not used!
                 bDocRequestSent |= aCmdLineArgs->GetOpenList( pRequest->aOpenList );
                 bDocRequestSent |= aCmdLineArgs->GetViewList( pRequest->aViewList );
                 bDocRequestSent |= aCmdLineArgs->GetStartList( pRequest->aStartList );
diff --git a/desktop/source/pkgchk/unopkg/unopkg_misc.cxx b/desktop/source/pkgchk/unopkg/unopkg_misc.cxx
index 68745ca..5dba571 100644
--- a/desktop/source/pkgchk/unopkg/unopkg_misc.cxx
+++ b/desktop/source/pkgchk/unopkg/unopkg_misc.cxx
@@ -402,12 +402,12 @@ Reference<XComponentContext> connectToOffice(
     bool verbose )
 {
     Sequence<OUString> args( 3 );
-    args[ 0 ] = OUSTR("-nologo");
-    args[ 1 ] = OUSTR("-nodefault");
+    args[ 0 ] = OUSTR("--nologo");
+    args[ 1 ] = OUSTR("--nodefault");
 
     OUString pipeId( ::dp_misc::generateRandomPipeId() );
     ::rtl::OUStringBuffer buf;
-    buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("-accept=pipe,name=") );
+    buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("--accept=pipe,name=") );
     buf.append( pipeId );
     buf.appendAscii( RTL_CONSTASCII_STRINGPARAM(";urp;") );
     args[ 2 ] = buf.makeStringAndClear();
@@ -418,7 +418,7 @@ Reference<XComponentContext> connectToOffice(
         dp_misc::writeConsole(
             OUSTR("Raising process: ") +
             appURL +
-            OUSTR("\nArguments: -nologo -nodefault ") +
+            OUSTR("\nArguments: --nologo --nodefault ") +
             args[2] +
             OUSTR("\n"));
     }
@@ -426,7 +426,7 @@ Reference<XComponentContext> connectToOffice(
     ::dp_misc::raiseProcess( appURL, args );
 
     if (verbose)
-        dp_misc::writeConsole("Ok.  Connecting...");
+        dp_misc::writeConsole("OK.  Connecting...");
 
     OSL_ASSERT( buf.getLength() == 0 );
     buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("uno:pipe,name=") );
@@ -438,7 +438,7 @@ Reference<XComponentContext> connectToOffice(
             buf.makeStringAndClear(), xLocalComponentContext ),
         UNO_QUERY_THROW );
     if (verbose)
-        dp_misc::writeConsole("Ok.\n");
+        dp_misc::writeConsole("OK.\n");
 
     return xRet;
 }
diff --git a/embeddedobj/qa/embedding/makefile.mk b/embeddedobj/qa/embedding/makefile.mk
index 78c6dfb..2ed6259 100755
--- a/embeddedobj/qa/embedding/makefile.mk
+++ b/embeddedobj/qa/embedding/makefile.mk
@@ -60,7 +60,7 @@ JARCOMPRESS 	= TRUE
 .IF "$(OFFICE)" == ""
 CT_APPEXECCOMMAND =
 .ELSE
-CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice -accept=socket,host=localhost,port=8100;urp;"
+CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice --accept=socket,host=localhost,port=8100;urp;"
 .ENDIF
 
 # test base is java complex
diff --git a/extensions/source/nsplugin/source/so_main.cxx b/extensions/source/nsplugin/source/so_main.cxx
index 127bedf..6bf83d9 100644
--- a/extensions/source/nsplugin/source/so_main.cxx
+++ b/extensions/source/nsplugin/source/so_main.cxx
@@ -314,16 +314,16 @@ Reference< lang::XMultiServiceFactory > SAL_CALL start_office(NSP_PIPE_FD read_f
 
         // accept string
         OSL_ASSERT( buf.getLength() == 0 );
-        buf.appendAscii( RTL_CONSTASCII_STRINGPARAM( "-accept=pipe,name=" ) );
+        buf.appendAscii( RTL_CONSTASCII_STRINGPARAM( "--accept=pipe,name=" ) );
         buf.append( aPluginPipeName );    //user installation path as pipe name
         buf.appendAscii( RTL_CONSTASCII_STRINGPARAM( ";urp;" ) );
         OUString sConnectStartString( buf.makeStringAndClear() );
 
         // arguments
         OUString args [] = {
-                OUSTR( "-nologo" ),
-                OUSTR( "-nodefault" ),
-                OUSTR( "-nolockcheck" ),
+                OUSTR( "--nologo" ),
+                OUSTR( "--nodefault" ),
+                OUSTR( "--nolockcheck" ),
                 sConnectStartString,
         };
 
diff --git a/filter/qa/complex/filter/detection/typeDetection/makefile.mk b/filter/qa/complex/filter/detection/typeDetection/makefile.mk
index 942c403..87d3480 100644
--- a/filter/qa/complex/filter/detection/typeDetection/makefile.mk
+++ b/filter/qa/complex/filter/detection/typeDetection/makefile.mk
@@ -53,7 +53,7 @@ JARCOMPRESS 	= TRUE
 .IF "$(OFFICE)" == ""
 CT_APPEXECCOMMAND =
 .ELSE
-CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice -accept=socket,host=localhost,port=8100;urp;"
+CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice --accept=socket,host=localhost,port=8100;urp;"
 .ENDIF
 
 # test base is java complex
diff --git a/framework/qa/complex/api_internal/CheckAPI.props b/framework/qa/complex/api_internal/CheckAPI.props
index 14b0107..b25eb9a 100755
--- a/framework/qa/complex/api_internal/CheckAPI.props
+++ b/framework/qa/complex/api_internal/CheckAPI.props
@@ -1,4 +1,4 @@
 ParamList=-OutProducer stats.SimpleFileOutProducer -OutputPath /dev/null
-#AppExecutionCommand=d:\\prj_new\\install\\src680_m17\\program\\soffice -norestore -nocrashreport -accept=socket,host=0,port=8100;urp;
+#AppExecutionCommand=d:\\prj_new\\install\\src680_m17\\program\\soffice --norestore --nocrashreport --accept=socket,host=0,port=8100;urp;
 # the test job list
 job1=sw.SwXTextTable
diff --git a/framework/qa/complex/framework/recovery/RecoveryTest.java b/framework/qa/complex/framework/recovery/RecoveryTest.java
index df75f73..0aa60a4 100755
--- a/framework/qa/complex/framework/recovery/RecoveryTest.java
+++ b/framework/qa/complex/framework/recovery/RecoveryTest.java
@@ -168,9 +168,9 @@ public class RecoveryTest extends ComplexTestCase {
         msg +="\tPlease run your command with the following parameter:\n\n";
         msg +="\t-AppExecutionCommand=OFFICEBINARY CONNECTIONSTRING\n\n";
         msg +="Example Windows:\n";
-        msg +="-AppExecutionCommand=C:\\office\\soffice.exe -accept=socket,host=localhost,port=8101;urp;\n\n";
+        msg +="-AppExecutionCommand=C:\\office\\soffice.exe --accept=socket,host=localhost,port=8101;urp;\n\n";
         msg +="Example UNIX:\n";
-        msg +="-AppExecutionCommand=/office/soffice \"-accept=socket,host=localhost,port=8101;urp;\"\n\n";
+        msg +="-AppExecutionCommand=/office/soffice \"--accept=socket,host=localhost,port=8101;urp;\"\n\n";
         msg+="NOTE: on UNIX be shure to have the connection string inside quotation mark!\n";
 
         assure(msg, param.get("AppExecutionCommand") != null && ! param.get("AppExecutionCommand").equals(""));
diff --git a/framework/qa/complex/framework/recovery/RecoveryTools.java b/framework/qa/complex/framework/recovery/RecoveryTools.java
index 2893694..ccd0e9e 100755
--- a/framework/qa/complex/framework/recovery/RecoveryTools.java
+++ b/framework/qa/complex/framework/recovery/RecoveryTools.java
@@ -267,14 +267,14 @@ public class RecoveryTools {
 
     /**
      * The office must be started WITH restore and crashreporter functionality.
-     * Therefore the parmater '<CODE>-norestore</CODE>' and '<CODE>-nocrashreport</CODE>'
+     * Therefore the paramater '<CODE>--norestore</CODE>' and '<CODE>--nocrashreport</CODE>'
      * was removed from the <CODE>AppExecutionCommand</CODE> parameter
      */
     public void removeParametersFromAppExecutionCommand(){
 
         //remove some params to start office
         String office = (String) param.get("AppExecutionCommand");
-        String[] params = {"-norestore", "-nocrashreport"};
+        String[] params = {"--norestore", "--nocrashreport"};
 
         for (int i = 0; i < params.length; i++){
             int index = office.indexOf(params[i]);
@@ -292,8 +292,8 @@ public class RecoveryTools {
     /**
      * This function uses accessibility to handle modal dialogs like the
      * "Are you sure" dialog.
-     * It cklick the named button given in parameter <CODE>buttonName</CODE>
-     * @param buttonName the name of the button wich should be chlicked
+     * It clicks the named button given in parameter <CODE>buttonName</CODE>
+     * @param buttonName the name of the button wich should be clicked
      */
     public void handleModalDialog(XMultiServiceFactory xMSF, String buttonName)
                 throws com.sun.star.accessibility.IllegalAccessibleComponentStateException
@@ -315,7 +315,7 @@ public class RecoveryTools {
             log.println("click ' " + buttonName + "' button..");
             oUITools.clickButton(buttonName);
         } catch ( java.lang.Exception e){
-            throw new com.sun.star.accessibility.IllegalAccessibleComponentStateException("Could not klick '"+buttonName +"' at modal dialog: " + e.toString());
+            throw new com.sun.star.accessibility.IllegalAccessibleComponentStateException("Could not click '"+buttonName +"' at modal dialog: " + e.toString());
         }
         pause();
     }
@@ -363,4 +363,4 @@ public class RecoveryTools {
    }
 
 
-}
\ No newline at end of file
+}
diff --git a/javaunohelper/com/sun/star/comp/helper/Bootstrap.java b/javaunohelper/com/sun/star/comp/helper/Bootstrap.java
index d962451..ae8caec 100644
--- a/javaunohelper/com/sun/star/comp/helper/Bootstrap.java
+++ b/javaunohelper/com/sun/star/comp/helper/Bootstrap.java
@@ -249,12 +249,12 @@ public class Bootstrap {
             // create call with arguments
             String[] cmdArray = new String[7];
             cmdArray[0] = fOffice.getPath();
-            cmdArray[1] = "-nologo";
-            cmdArray[2] = "-nodefault";
-            cmdArray[3] = "-norestore";
-            cmdArray[4] = "-nocrashreport";
-            cmdArray[5] = "-nolockcheck";
-            cmdArray[6] = "-accept=pipe,name=" + sPipeName + ";urp;";
+            cmdArray[1] = "--nologo";
+            cmdArray[2] = "--nodefault";
+            cmdArray[3] = "--norestore";
+            cmdArray[4] = "--nocrashreport";
+            cmdArray[5] = "--nolockcheck";
+            cmdArray[6] = "--accept=pipe,name=" + sPipeName + ";urp;";
 
             // start office process
             Process p = Runtime.getRuntime().exec( cmdArray );
diff --git a/jurt/workbench/com/sun/star/comp/urlresolver/UrlResolver_Test.java b/jurt/workbench/com/sun/star/comp/urlresolver/UrlResolver_Test.java
index a78a2df..c2b67c1 100644
--- a/jurt/workbench/com/sun/star/comp/urlresolver/UrlResolver_Test.java
+++ b/jurt/workbench/com/sun/star/comp/urlresolver/UrlResolver_Test.java
@@ -37,7 +37,7 @@ import com.sun.star.uno.UnoRuntime;
 //import com.sun.star.connection.NoConnectionException;
 
 /** start the office with these options <br>
-    soffice -accept=socket,host=localhost,port=8100;urp;
+    soffice --accept=socket,host=localhost,port=8100;urp;
 */
 public class UrlResolver_Test
 {
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Install.txt b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Install.txt
index fc7c95a..79a1ee2 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Install.txt
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Install.txt
@@ -6,5 +6,5 @@
 (5) copy from an existing java installation the runtime library "jawt" (e.g. jawt.dll for windows)
 	into this directory
 (6) copy "api/<platform>/bin/nativelib.dll" (for windows) to "api/<platform>/class"
-(7) start an office  : "soffice -accept=socket,host=localhost,port=2083;urp;"
+(7) start an office  : "soffice --accept=socket,host=localhost,port=2083;urp;"
 (8) goto "api/<platform>/class" and start java applet: "java -jar desktop.jar"
diff --git a/odk/examples/DevelopersGuide/ProfUNO/CppBinding/Makefile b/odk/examples/DevelopersGuide/ProfUNO/CppBinding/Makefile
index 23c86e5..bb1dfc2 100644
--- a/odk/examples/DevelopersGuide/ProfUNO/CppBinding/Makefile
+++ b/odk/examples/DevelopersGuide/ProfUNO/CppBinding/Makefile
@@ -95,7 +95,7 @@ ProUNOCppBindingExample : $(APP1_BINARY) $(APP2_BINARY)
 	@echo $(SQM)      $(SQM)the additional office types via the UNO environment variable -env:URE_MORE_TYPES=... 
 	@echo $(SQM)      $(SQM)Before you can run this example you have to start your office in listening mode.
 	@echo -
-	@echo $(SQM)  $(SQM)soffice "$(QM)-accept=socket,host=localhost,port=2083;urp;StarOffice.ServiceManager$(QM)"
+	@echo $(SQM)  $(SQM)soffice "$(QM)--accept=socket,host=localhost,port=2083;urp;StarOffice.ServiceManager$(QM)"
 	@echo -----
 	@echo Please use one of the following commands to execute the examples!
 	@echo -
diff --git a/odk/examples/DevelopersGuide/ProfUNO/InterprocessConn/Makefile b/odk/examples/DevelopersGuide/ProfUNO/InterprocessConn/Makefile
index deaade0..e0565dd 100644
--- a/odk/examples/DevelopersGuide/ProfUNO/InterprocessConn/Makefile
+++ b/odk/examples/DevelopersGuide/ProfUNO/InterprocessConn/Makefile
@@ -70,7 +70,7 @@ $(EXAMPLE_NAME) : $(CLASSFILES)
 	@echo Note: For these examples you need a running office listening on port 2083.
 	@echo $(SQM)      $(SQM)Before you run these examples you have to start your office with
 	@echo -
-	@echo $(SQM)  $(SQM)soffice "$(QM)-accept=socket,host=localhost,port=2083;urp;StarOffice.ServiceManager$(QM)"
+	@echo $(SQM)  $(SQM)soffice "$(QM)--accept=socket,host=localhost,port=2083;urp;StarOffice.ServiceManager$(QM)"
 	@echo -----
 	@echo Please use one of the following commands to execute the examples!
 	@echo -
diff --git a/odk/examples/cpp/DocumentLoader/Makefile b/odk/examples/cpp/DocumentLoader/Makefile
index 02a872a..4889262 100644
--- a/odk/examples/cpp/DocumentLoader/Makefile
+++ b/odk/examples/cpp/DocumentLoader/Makefile
@@ -94,7 +94,7 @@ CppDocumentLoaderExample : $(OUT_BIN)/DocumentLoader$(EXE_EXT)
 	@echo $(SQM)      $(SQM)the additional office types via the UNO environment variable -env:URE_MORE_TYPES=... 
 	@echo $(SQM)      $(SQM)Before you can run this example you have to start your office in listening mode.
 	@echo -
-	@echo $(SQM)  $(SQM)soffice "$(QM)-accept=socket,host=localhost,port=2083;urp;StarOffice.ServiceManager$(QM)"
+	@echo $(SQM)  $(SQM)soffice "$(QM)--accept=socket,host=localhost,port=2083;urp;StarOffice.ServiceManager$(QM)"
 	@echo --------------------------------------------------------------------------------
 
 %.run: $(OUT_BIN)/DocumentLoader$(EXE_EXT)
diff --git a/odk/examples/examples.html b/odk/examples/examples.html
index cbc6732..9271abe 100644
--- a/odk/examples/examples.html
+++ b/odk/examples/examples.html
@@ -443,7 +443,7 @@
 		  running this program you should invoke the office with the following
 		  command:
 		  <blockquote>
-		  <code>soffice &quot;-accept=socket,host=localhost,port=2083;urp;StarOffice.ServiceManager&quot;</code>
+		  <code>soffice &quot;--accept=socket,host=localhost,port=2083;urp;StarOffice.ServiceManager&quot;</code>
 		  </blockquote>
 		  You can also customize the mentioned host and port to your needs.
 		  </td>
diff --git a/package/qa/ofopxmlstorages/makefile.mk b/package/qa/ofopxmlstorages/makefile.mk
index c829458..43ce6f2 100644
--- a/package/qa/ofopxmlstorages/makefile.mk
+++ b/package/qa/ofopxmlstorages/makefile.mk
@@ -67,7 +67,7 @@ JARCOMPRESS 	= TRUE
 .IF "$(OFFICE)" == ""
 CT_APPEXECCOMMAND =
 .ELSE
-CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice -accept=socket,host=localhost,port=8100;urp;"
+CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice --accept=socket,host=localhost,port=8100;urp;"
 .ENDIF
 
 # test base is java complex
diff --git a/package/qa/storages/makefile.mk b/package/qa/storages/makefile.mk
index 95fe75a..7c85eeb 100644
--- a/package/qa/storages/makefile.mk
+++ b/package/qa/storages/makefile.mk
@@ -92,7 +92,7 @@ JARCOMPRESS 	= TRUE
 .IF "$(OFFICE)" == ""
 CT_APPEXECCOMMAND =
 .ELSE
-CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice -accept=socket,host=localhost,port=8100;urp;"
+CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice --accept=socket,host=localhost,port=8100;urp;"
 .ENDIF
 
 # test base is java complex
diff --git a/qadevOOo/runner/graphical/JPEGComparator.java b/qadevOOo/runner/graphical/JPEGComparator.java
index a643b2b..3716d5d 100644
--- a/qadevOOo/runner/graphical/JPEGComparator.java
+++ b/qadevOOo/runner/graphical/JPEGComparator.java
@@ -807,7 +807,7 @@ public class JPEGComparator extends EnhancedComplexTestCase
 ////            "-DOC_COMPARATOR_REFERENCE_CREATOR_TYPE", "PDF",      /* default: "OOo" */
 ////            "-DOC_COMPARATOR_REFERENCE_CREATOR_TYPE", "msoffice", /* default: "OOo" */
 ////            "-OFFICE_VIEWABLE", "false",
-////            "-AppExecutionCommand", "\"C:/Programme/sun/staroffice 9/program/soffice.exe\"  -norestore -nocrashreport -accept=pipe,name=ll93751;urp;",
+////            "-AppExecutionCommand", "\"C:/Programme/sun/staroffice 9/program/soffice.exe\"  --norestore --nocrashreport --accept=pipe,name=ll93751;urp;",
 //            "-NoOffice"
 //        };
 //
diff --git a/qadevOOo/runner/graphical/JPEGCreator.java b/qadevOOo/runner/graphical/JPEGCreator.java
index 7deee0d..b8aa272 100644
--- a/qadevOOo/runner/graphical/JPEGCreator.java
+++ b/qadevOOo/runner/graphical/JPEGCreator.java
@@ -446,7 +446,7 @@ private static void convertToWidth340(String _sFrom, String _To)
 //////            "-DOC_COMPARATOR_REFERENCE_CREATOR_TYPE", "PDF",      /* default: "OOo" */
 //////            "-DOC_COMPARATOR_REFERENCE_CREATOR_TYPE", "msoffice", /* default: "OOo" */
 //////            "-OFFICE_VIEWABLE", "false",
-////            "-AppExecutionCommand", "\"C:/Programme/sun/staroffice 9/program/soffice.exe\"  -norestore -nocrashreport -accept=pipe,name=ll93751;urp;",
+////            "-AppExecutionCommand", "\"C:/Programme/sun/staroffice 9/program/soffice.exe\"  --norestore --nocrashreport --accept=pipe,name=ll93751;urp;",
 ////            "-NoOffice"
 ////        };
 //
@@ -466,7 +466,7 @@ private static void convertToWidth340(String _sFrom, String _To)
 ////            "-DOC_COMPARATOR_REFERENCE_CREATOR_TYPE", "PDF",      /* default: "OOo" */
 ////            "-DOC_COMPARATOR_REFERENCE_CREATOR_TYPE", "msoffice", /* default: "OOo" */
 ////            "-OFFICE_VIEWABLE", "false",
-//            "-AppExecutionCommand", "\"C:/Programme/sun/staroffice 9/program/soffice.exe\"  -norestore -nocrashreport -accept=pipe,name=ll93751;urp;",
+//            "-AppExecutionCommand", "\"C:/Programme/sun/staroffice 9/program/soffice.exe\"  --norestore --nocrashreport --accept=pipe,name=ll93751;urp;",
 //            "-NoOffice"
 //        };
 //
diff --git a/qadevOOo/runner/graphical/PostscriptCreator.java b/qadevOOo/runner/graphical/PostscriptCreator.java
index 7109b48..7bd9833 100644
--- a/qadevOOo/runner/graphical/PostscriptCreator.java
+++ b/qadevOOo/runner/graphical/PostscriptCreator.java
@@ -114,7 +114,7 @@ public class PostscriptCreator extends EnhancedComplexTestCase
 //////            "-DOC_COMPARATOR_REFERENCE_CREATOR_TYPE", "PDF",      /* default: "OOo" */
 //////            "-DOC_COMPARATOR_REFERENCE_CREATOR_TYPE", "msoffice", /* default: "OOo" */
 //////            "-OFFICE_VIEWABLE", "false",
-////            "-AppExecutionCommand", "\"C:/home/ll93751/staroffice9_DEV300_m25/Sun/StarOffice 9/program/soffice.exe\"  -norestore -nocrashreport -accept=pipe,name=ll93751;urp;",
+////            "-AppExecutionCommand", "\"C:/home/ll93751/staroffice9_DEV300_m25/Sun/StarOffice 9/program/soffice.exe\"  --norestore --nocrashreport --accept=pipe,name=ll93751;urp;",
 //////            "-NoOffice"
 //            "-DOC_COMPARATOR_PRINT_MAX_PAGE","9999",
 //            "-DOC_COMPARATOR_GFX_OUTPUT_DPI_RESOLUTION","180",
@@ -127,7 +127,7 @@ public class PostscriptCreator extends EnhancedComplexTestCase
 //            "-OFFICE_VIEWABLE","true",
 //            "-wntmsci.DOC_COMPARATOR_INPUT_PATH","\\\\so-gfxcmp-lin\\doc-pool\\LLA_test\\issue_79214.odb",
 //            "-wntmsci.DOC_COMPARATOR_OUTPUT_PATH","\\\\so-gfxcmp-lin\\gfxcmp-data\\wntmsci\\convwatch-output\\LLA_test\\DEV300_m11",
-//            "-wntmsci.AppExecutionCommand","\"C:\\gfxcmp\\programs\\staroffice8_DEV300_m11\\Sun\\StarOffice 9\\program\\soffice.exe\"  -norestore -nocrashreport -accept=pipe,name=ll93751;urp;",
+//            "-wntmsci.AppExecutionCommand","\"C:\\gfxcmp\\programs\\staroffice8_DEV300_m11\\Sun\\StarOffice 9\\program\\soffice.exe\"  --norestore --nocrashreport --accept=pipe,name=ll93751;urp;",
 //            "-wntmsci.AppKillCommand","\"C:\\bin\\pskill.exe soffice.bin;C:\\bin\\pskill.exe winword;C:\\bin\\pskill.exe excel\"",
 //
 //        };
diff --git a/qadevOOo/runner/helper/OfficeProvider.java b/qadevOOo/runner/helper/OfficeProvider.java
index 1d4950e..3d46972 100644
--- a/qadevOOo/runner/helper/OfficeProvider.java
+++ b/qadevOOo/runner/helper/OfficeProvider.java
@@ -311,7 +311,7 @@ public class OfficeProvider implements AppProvider
             else
             {
                 System.out.println("Could not connect an Office and cannot start one.\n".concat("please start an office with following parameter:\n").
-                        concat("\nsoffice -accept=").concat((String) param.get("ConnectionString")).concat(";urp;\n"));
+                        concat("\nsoffice --accept=").concat((String) param.get("ConnectionString")).concat(";urp;\n"));
                 if (bAppExecutionHasWarning)
                 {
                     System.out.println(errorMessage);
@@ -751,7 +751,7 @@ public class OfficeProvider implements AppProvider
         if (command.indexOf(sysBinDir) == -1)
         {
             command = sysBinDir + System.getProperty("file.separator") + "soffice" +
-                    " -norestore -accept=" + connectionString + ";urp;";
+                    " --norestore --accept=" + connectionString + ";urp;";
         }
 
         dbg("update AppExecutionCommand: " + command);
diff --git a/qadevOOo/runner/util/utils.java b/qadevOOo/runner/util/utils.java
index f51b79a..541ca75 100644
--- a/qadevOOo/runner/util/utils.java
+++ b/qadevOOo/runner/util/utils.java
@@ -816,14 +816,14 @@ public class utils {
                     boolean gotNoAccept = true;
                     while (commandTokens.hasMoreElements()) {
                         String officeParam = commandTokens.nextToken();
-                        if (officeParam.indexOf("-accept=") != -1) {
+                        if (officeParam.indexOf("--accept=") != -1) {
                             gotNoAccept = false;
                             errorMessage = validateConnectString(officeParam, true);
                         }
                     }
                     if (gotNoAccept) {
                         errorMessage = "Error: Your 'AppExecutionCommand' parameter does not " +
-                            "contain a '-accept' parameter for connecting the office.";
+                            "contain a '--accept' parameter for connecting the office.";
                     }
                 }
             }
@@ -841,7 +841,7 @@ public class utils {
     public static String validateConnectString(String connectString, boolean checkAppExecutionCommand) {
         String acceptPrefix = "";
         if (checkAppExecutionCommand) {
-            acceptPrefix = "-accept=";
+            acceptPrefix = "--accept=";
         }
 
         String errorMessage = "OK";
@@ -850,7 +850,7 @@ public class utils {
             if (connectString.indexOf(acceptPrefix + "socket,host=") == -1 ||
                 connectString.indexOf("port=") == -1) {
                 if (checkAppExecutionCommand) {
-                    errorMessage = "Error: The '-accept' parameter contains a syntax error: It should be like: '-accept=socket,host=localhost,port=8100;urp;";
+                    errorMessage = "Error: The '--accept' parameter contains a syntax error: It should be like: '--accept=socket,host=localhost,port=8100;urp;";
                 } else {
                     errorMessage = "Error: The 'ConnectionString' parameter contains a syntax error: It should be like: 'socket,host=localhost,port=8100'";
                 }
@@ -858,14 +858,14 @@ public class utils {
         } else if (connectString.indexOf("pipe") != -1) {
             if (connectString.indexOf(acceptPrefix + "pipe,name=") == -1) {
                 if (checkAppExecutionCommand) {
-                    errorMessage = "Error: The '-accept' parameter contains a syntax error: It should be like: '-accept=pipe,name=myuniquename;urp;'";
+                    errorMessage = "Error: The '--accept' parameter contains a syntax error: It should be like: '--accept=pipe,name=myuniquename;urp;'";
                 } else {
                     errorMessage = "Error: The 'ConnectionString' parameter contains a syntax error: It should be like: 'pipe,name=myuniquename'";
                 }
             }
         } else {
             if (checkAppExecutionCommand) {
-                errorMessage = "Warning: The '-accept' parameter contains an unknown connection method.";
+                errorMessage = "Warning: The '--accept' parameter contains an unknown connection method.";
             } else {
                 errorMessage = "Warning: The 'ConnectionString' parameter contains an unknown connection method.";
             }
diff --git a/reportdesign/qa/complex/reportdesign/runner.props b/reportdesign/qa/complex/reportdesign/runner.props
index d894366..2312de9 100755
--- a/reportdesign/qa/complex/reportdesign/runner.props
+++ b/reportdesign/qa/complex/reportdesign/runner.props
@@ -5,8 +5,8 @@ unxlngi.DOC_COMPARATOR_OUTPUT_PATH=/net/so-gfxcmp-lin/export/gfxcmp/document-poo
 DB_CONNECTION_STRING=server:jakobus,db:jobs_convwatch,user:admin,passwd:admin
 
 # Set path to an existing office installation
-wntmsci.AppExecutionCommand=C:\\home\\${USERNAME}\\staroffice8\\program\\soffice.exe  -norestore -nocrashreport -accept=socket,host=localhost,port=8100;urp;
-unxlngi.AppExecutionCommand=/opt/staroffice8/program/soffice                          -norestore -nocrashreport -accept=socket,host=localhost,port=8100;urp;
+wntmsci.AppExecutionCommand=C:\\home\\${USERNAME}\\staroffice8\\program\\soffice.exe  --norestore --nocrashreport --accept=socket,host=localhost,port=8100;urp;
+unxlngi.AppExecutionCommand=/opt/staroffice8/program/soffice                          --norestore --nocrashreport --accept=socket,host=localhost,port=8100;urp;
 
 # Set the 'Continue' Property to true, to leave out already done tests.
 Continue=true
diff --git a/sal/osl/unx/signal.c b/sal/osl/unx/signal.c
index 6a6dd1d..71bd5fd 100644
--- a/sal/osl/unx/signal.c
+++ b/sal/osl/unx/signal.c
@@ -512,12 +512,12 @@ static int ReportCrash( int Signal )
     {
         if ( osl_Process_E_None == osl_getCommandArg( argi, &ustrCommandArg ) )
         {
-            if ( 0 == rtl_ustr_ascii_compare( rtl_uString_getStr( ustrCommandArg ), "-nocrashreport" ) )
+            if ( 0 == rtl_ustr_ascii_compare( rtl_uString_getStr( ustrCommandArg ), "--nocrashreport" ) )
             {
                 rtl_uString_release( ustrCommandArg );
                 return -1;
             }
-            else if ( 0 == rtl_ustr_ascii_compare( rtl_uString_getStr( ustrCommandArg ), "-autocrashreport" ) )
+            else if ( 0 == rtl_ustr_ascii_compare( rtl_uString_getStr( ustrCommandArg ), "--autocrashreport" ) )
             {
                 bAutoCrashReport = sal_True;
             }
diff --git a/sal/osl/w32/signal.cxx b/sal/osl/w32/signal.cxx
index 6b59a1d..2547a62 100644
--- a/sal/osl/w32/signal.cxx
+++ b/sal/osl/w32/signal.cxx
@@ -131,12 +131,12 @@ static BOOL ReportCrash( LPEXCEPTION_POINTERS lpEP )
     for ( argi = 1; argi < __argc; argi++ )
     {
         if (
-            0 == stricmp( __argv[argi], "-nocrashreport" ) ||
+            0 == stricmp( __argv[argi], "--nocrashreport" ) ||
             0 == stricmp( __argv[argi], "/nocrashreport" )
             )
             return FALSE;
         else if (
-            0 == stricmp( __argv[argi], "-autocrashreport" ) ||
+            0 == stricmp( __argv[argi], "--autocrashreport" ) ||
             0 == stricmp( __argv[argi], "/autocrashreport" )
             )
             fAutoReport = TRUE;
diff --git a/sc/qa/complex/calcPreview/makefile.mk b/sc/qa/complex/calcPreview/makefile.mk
index 864e149..912a29a 100755
--- a/sc/qa/complex/calcPreview/makefile.mk
+++ b/sc/qa/complex/calcPreview/makefile.mk
@@ -84,7 +84,7 @@ ALLTAR : javatest
 # .IF "$(OFFICE)" == ""
 # CT_APPEXECCOMMAND =
 # .ELSE
-# CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice -accept=socket,host=localhost,port=8100;urp;"
+# CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice --accept=socket,host=localhost,port=8100;urp;"
 # .ENDIF
 # 
 # # test base is java complex
diff --git a/scp2/source/calc/registryitem_calc.scp b/scp2/source/calc/registryitem_calc.scp
index 19d4ba1..9ebfade 100644
--- a/scp2/source/calc/registryitem_calc.scp
+++ b/scp2/source/calc/registryitem_calc.scp
@@ -97,7 +97,7 @@ RegistryItem gid_Regitem_Clsid__7b342dc4_139a_4a46_8a93_Db0827ccee9c__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Calc_Bin;
     Subkey = "CLSID\{7B342DC4-139A-4a46-8A93-DB0827CCEE9C}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__7b342dc4_139a_4a46_8a93_Db0827ccee9c__Miscstatus
@@ -216,7 +216,7 @@ RegistryItem gid_Regitem_Clsid__7fa8ae11_B3e3_4d88_Aabf_255526cd1ce8__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Calc_Bin;
     Subkey = "CLSID\{7FA8AE11-B3E3-4D88-AABF-255526CD1CE8}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__7fa8ae11_B3e3_4d88_Aabf_255526cd1ce8__Miscstatus
diff --git a/scp2/source/draw/registryitem_draw.scp b/scp2/source/draw/registryitem_draw.scp
index 561dbf1..c9d4e9e 100644
--- a/scp2/source/draw/registryitem_draw.scp
+++ b/scp2/source/draw/registryitem_draw.scp
@@ -97,7 +97,7 @@ RegistryItem gid_Regitem_Clsid__41662fc2_0d57_4aff_Ab27_Ad2e12e7c273__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Draw_Bin;
     Subkey = "CLSID\{41662FC2-0D57-4aff-AB27-AD2E12E7C273}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__41662fc2_0d57_4aff_Ab27_Ad2e12e7c273__Miscstatus
@@ -216,7 +216,7 @@ RegistryItem gid_Regitem_Clsid__448bb771_Cfe2_47c4_Bcdf_1fbf378e202c__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Draw_Bin;
     Subkey = "CLSID\{448BB771-CFE2-47C4-BCDF-1FBF378E202C}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__448bb771_Cfe2_47c4_Bcdf_1fbf378e202c__Miscstatus
diff --git a/scp2/source/impress/registryitem_impress.scp b/scp2/source/impress/registryitem_impress.scp
index 7b26fc5..aeee461 100644
--- a/scp2/source/impress/registryitem_impress.scp
+++ b/scp2/source/impress/registryitem_impress.scp
@@ -97,7 +97,7 @@ RegistryItem gid_Regitem_Clsid__E5a0b632_Dfba_4549_9346_E414da06e6f8__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Impress_Bin;
     Subkey = "CLSID\{E5A0B632-DFBA-4549-9346-E414DA06E6F8}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__E5a0b632_Dfba_4549_9346_E414da06e6f8__Miscstatus
@@ -216,7 +216,7 @@ RegistryItem gid_Regitem_Clsid__Ee5d1ea4_D445_4289_B2fc_55fc93693917__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Impress_Bin;
     Subkey = "CLSID\{EE5D1EA4-D445-4289-B2FC-55FC93693917}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__Ee5d1ea4_D445_4289_B2fc_55fc93693917__Miscstatus
diff --git a/scp2/source/math/registryitem_math.scp b/scp2/source/math/registryitem_math.scp
index 449a6c6..9d043ce 100644
--- a/scp2/source/math/registryitem_math.scp
+++ b/scp2/source/math/registryitem_math.scp
@@ -96,8 +96,8 @@ RegistryItem gid_Regitem_Clsid__D0484de6_Aaee_468a_991f_8d4b0737b57a__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Math_Bin;
     Subkey = "CLSID\{D0484DE6-AAEE-468a-991F-8D4B0737B57A}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
-End
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
+    End
 
 RegistryItem gid_Regitem_Clsid__D0484de6_Aaee_468a_991f_8d4b0737b57a__Miscstatus
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
@@ -215,7 +215,7 @@ RegistryItem gid_Regitem_Clsid__D2d59cd1_0a6a_4d36_Ae20_47817077d57c__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Math_Bin;
     Subkey = "CLSID\{D2D59CD1-0A6A-4D36-AE20-47817077D57C}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__D2d59cd1_0a6a_4d36_Ae20_47817077d57c__Miscstatus
diff --git a/scp2/source/ooo/registryitem_ooo.scp b/scp2/source/ooo/registryitem_ooo.scp
index 6386212..2afd875 100644
--- a/scp2/source/ooo/registryitem_ooo.scp
+++ b/scp2/source/ooo/registryitem_ooo.scp
@@ -67,7 +67,7 @@ RegistryItem gid_Regitem_Clsid__3ecf78f0_B1_11d2_8ebe_005ad848af__Localserver32
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     Subkey = "CLSID\{82154420-0FBF-11d4-8313-005004526AB4}\LocalServer32";
     ModuleID = gid_Module_Root;
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__3ecf78f0_B1_11d2_8ebe_005ad848af__Notinsertable
diff --git a/scp2/source/writer/registryitem_writer.scp b/scp2/source/writer/registryitem_writer.scp
index ef40203..c6f08f2 100644
--- a/scp2/source/writer/registryitem_writer.scp
+++ b/scp2/source/writer/registryitem_writer.scp
@@ -97,7 +97,7 @@ RegistryItem gid_Regitem_Clsid__30a2652a_Ddf7_45e7_Aca6_3eab26fc8a4e__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Wrt_Bin;
     Subkey = "CLSID\{30A2652A-DDF7-45e7-ACA6-3EAB26FC8A4E}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__30a2652a_Ddf7_45e7_Aca6_3eab26fc8a4e__Miscstatus
@@ -216,7 +216,7 @@ RegistryItem gid_Regitem_Clsid__F616b81f_7bb8_4f22_B8a5_47428d59f8ad__Localserve
     ParentID = PREDEFINED_HKEY_CLASSES_ROOT;
     ModuleID = gid_Module_Prg_Wrt_Bin;
     Subkey = "CLSID\{F616B81F-7BB8-4F22-B8A5-47428D59F8AD}\LocalServer32";
-    Value = "<progpath>\program\soffice.exe -nodefault -nologo";
+    Value = "<progpath>\program\soffice.exe --nodefault --nologo";
 End
 
 RegistryItem gid_Regitem_Clsid__F616b81f_7bb8_4f22_B8a5_47428d59f8ad__Miscstatus
diff --git a/scripting/java/org/openoffice/idesupport/localoffice/LocalOfficeImpl.java b/scripting/java/org/openoffice/idesupport/localoffice/LocalOfficeImpl.java
index fa42a7b..d3d7045 100755
--- a/scripting/java/org/openoffice/idesupport/localoffice/LocalOfficeImpl.java
+++ b/scripting/java/org/openoffice/idesupport/localoffice/LocalOfficeImpl.java
@@ -126,7 +126,7 @@ System.out.println("*** LocalOfficeImpl.refreshStorage: DONE");
      * Boot straps UNO.
      *
      * The office has to be started with following string:
-     * "-accept=socket,host=localhost,port=<PORT>;urp;StarOffice.ServiceManager"
+     * "--accept=socket,host=localhost,port=<PORT>;urp;StarOffice.ServiceManager"
      *
      * @param port is a communication port.
      */
diff --git a/scripting/source/pyprov/msgbox.py b/scripting/source/pyprov/msgbox.py
index b276d76..c5c57f2 100644
--- a/scripting/source/pyprov/msgbox.py
+++ b/scripting/source/pyprov/msgbox.py
@@ -240,8 +240,8 @@ if __name__ == '__main__':
                     "com.sun.star.bridge.UnoUrlResolver", localContext )
 
     # connect to the running office
-    # OOo has to be launched in listen mode as
-    # ./soffice "-accept=socket,host=localhost,port=2002;urp;"
+    # LibO has to be launched in listen mode as
+    # ./soffice "--accept=socket,host=localhost,port=2002;urp;"
     ctx = resolver.resolve( "uno:socket,host=localhost,port=2002;urp;StarOffice.ComponentContext" )
     myBox = MsgBox(ctx)
     myBox.addButton("Yes")
diff --git a/scripting/source/pyprov/officehelper.py b/scripting/source/pyprov/officehelper.py
index 610ac5f..84b7cce 100755
--- a/scripting/source/pyprov/officehelper.py
+++ b/scripting/source/pyprov/officehelper.py
@@ -62,8 +62,8 @@ def bootstrap():
         random.seed()
         sPipeName = "uno" + str(random.random())[2:]
         
-        # Start the office proces, don't check for exit status since an exception is caught anyway if the office terminates unexpectedly.
-        cmdArray = (sOffice, "-nologo", "-nodefault", "".join(["-accept=pipe,name=", sPipeName, ";urp;"]))        
+        # Start the office process, don't check for exit status since an exception is caught anyway if the office terminates unexpectedly.
+        cmdArray = (sOffice, "--nologo", "--nodefault", "".join(["--accept=pipe,name=", sPipeName, ";urp;"]))
         os.spawnv(os.P_NOWAIT, sOffice, cmdArray)
 			
         # ---------
diff --git a/sysui/desktop/man/libreoffice.1 b/sysui/desktop/man/libreoffice.1
index 92ed363..ebc3843 100644
--- a/sysui/desktop/man/libreoffice.1
+++ b/sysui/desktop/man/libreoffice.1
@@ -5,13 +5,13 @@ libreoffice \- LibreOffice office suite
 .SH SYNOPSIS
 .B libreoffice
 [\fB\-\-accept\=\fIaccept\-string\fR] [\fB\-\-base\fR] [\fB\-\-calc\fR]
-[\fB\-\-convert\-to\fR output_file_extension[:output_filter_name] [\-outdir output_dir] \fIfile\fR]...
+[\fB\-\-convert\-to\fR output_file_extension[:output_filter_name] [\-\-outdir output_dir] \fIfile\fR]...
 [\fB\-\-display \fIdisplay\fR] [\fB\-\-draw\fR] [\fB\-\-global\fR] [\fB\-\-headless\fR]
 [\fB\-\-help\fR|\fB\-h\fR|\fB\-?\fR] [\fB\-\-impress\fR] [\fB\-\-invisible\fR] [\fB\-\-infilter="<filter>"\fR]
-[\fB\-\-math\fR] [\fB\-\-minimized\fR] [\fB\-n \fIfile\fR]... [\fB\-nodefault\fR]
+[\fB\-\-math\fR] [\fB\-\-minimized\fR] [\fB\-n \fIfile\fR]... [\fB\-\-nodefault\fR]
 [\fB\-\-nolockcheck\fR] [\fB\-\-nologo\fR] [\fB\-\-norestore\fR]
 [\fB\-o \fIfile\fR]... [\fB\-p \fIfile\fR...]
-[\fB\-\-print\-to\-file [\-printer\-name printer_name] [\-outdir output_dir] file]...
+[\fB\-\-print\-to\-file [\-\-printer\-name printer_name] [\-\-outdir output_dir] file]...
 [\fB\-\-pt \fIprintername\fR \fIfile\fR...]
 [\fB\-\-show \fIImpress file\fR]... [\fB\-\-unaccept=\fIaccept\-string\fR]
 [\fB\-\-terminate_after_init\fR] [\fB\-\-view \fIfile\fR]... [\fB\-\-web\fR]
@@ -60,9 +60,9 @@ Starts the wizard for a new Base document.
 Starts with a new Calc document.
 
 .TP
-\fB\-\-convert\-to\fR output_file_extension[:output_filter_name] [\-outdir output_dir] \fIfile\fR...
+\fB\-\-convert\-to\fR output_file_extension[:output_filter_name] [\-\-outdir output_dir] \fIfile\fR...
 Batch converts files.
-If \fI-outdir\fR is not specified then the current working directory is used as the output directory
+If \fI\-\-outdir\fR is not specified then the current working directory is used as the output directory
 for the converted files.
 
 Examples:
@@ -71,7 +71,7 @@ Examples:
 
 Converts all .doc files to PDFs.
 
-\fB\-\-convert\-to\fR pdf:writer_pdf_Export \-outdir /home/user *.doc
+\fB\-\-convert\-to\fR pdf:writer_pdf_Export \-\-outdir /home/user *.doc
 
 Converts all .doc files to PDFs using the settings in the Writer PDF export dialog and saving them
 in /home/user.
@@ -117,7 +117,7 @@ LO can be controlled and documents and dialogs can be opened via the API.
 When started with this parameter, it can only be quit using the taskmanager (Windows)
 or the kill command (UNIX based systems).
 
-\-quickstart does not work with this parameter.
+\-\-quickstart does not work with this parameter.
 
 .TP
 \fB\-\-infilter="<filter>"\fR
@@ -138,10 +138,10 @@ Creates the a new document from the given templates.
 
 .TP
 \fB\-\-nodefault\fR
-Starts LO without creating an new document.
-The next time you start LO, the welcome screen is show.
+Starts LO without creating a new document.
+The next time you start LO, the welcome screen is shown.
 
-It's used together with \fB\-nologo\fR by quick starters. Note that \fB\-quickstart\fR
+It's used together with \fB\-\-nologo\fR by quick starters. Note that \fB\-\-quickstart\fR
 has no longer been supported since OpenOffice.org 2.0.0.
 
 .TP
@@ -155,7 +155,7 @@ Disables the splash screen at program start.
 .TP
 \fB\-\-norestore\fR
 Disables restart and file recovery after a system crash. It is possible that LO
-will try to restore a file it keeps crashing on, if that happens \fB\-norestore\fR
+will try to restore a file it keeps crashing on, if that happens \fB\-\-norestore\fR
 is the only way to start LO.
 
 .TP
@@ -176,10 +176,10 @@ does not appear.
 If the file name contains spaces, then it must be enclosed in quotation marks.
 
 .TP
-\fB\-\-print\-to\-file [\-printer\-name printer_name] [\-outdir output_dir] file...
+\fB\-\-print\-to\-file [\-\-printer\-name printer_name] [\-\-outdir output_dir] file...
 Batch print files to file.
-If \-printer\-name is not specified the default printer is used.
-If \-outdir is not specified then the current working directory is used as the output directory
+If \-\-printer\-name is not specified the default printer is used.
+If \-\-outdir is not specified then the current working directory is used as the output directory
 for the converted files.
 
 Examples:
@@ -188,7 +188,7 @@ Examples:
 
 Prints all .doc files to the current working directory using the default printer.
 
-\-\-print\-to\-file \-printer\-name nasty_lowres_printer \-outdir /home/user *.doc
+\-\-print\-to\-file \-\-printer\-name nasty_lowres_printer \-\-outdir /home/user *.doc
 
 Prints all .doc files to /home/user directory using the nasty_lowres_printer.
 
@@ -200,7 +200,7 @@ screen does not appear.
 If a file name contains spaces, then it must be enclosed in quotation marks.
 
 .TP
-\fB\-\-quickstart \fB\-quickstart=no
+\fB\-\-quickstart \fB\-\-quickstart=no
 Starts LO with it's quick starter.
 \fB\-\-quickstart disable the quick starter.
 
@@ -212,7 +212,7 @@ Opens the given Impress files, starts the presentation and quits after they have
 
 .TP
 \fB\-\-unaccept=\fIaccept\-string\fR
-Closes an acceptor that was created with \fB\-accept\fR option.
+Closes an acceptor that was created with \fB\-\-accept\fR option.
 
 Use \fB\-\-unaccept\fR=\fIall\fR to close all open acceptors.
 
diff --git a/toolkit/qa/complex/toolkit/UnitConversion.java b/toolkit/qa/complex/toolkit/UnitConversion.java
index ef100a7..ea93f31 100644
--- a/toolkit/qa/complex/toolkit/UnitConversion.java
+++ b/toolkit/qa/complex/toolkit/UnitConversion.java
@@ -92,7 +92,7 @@ public class UnitConversion
     /**
      * The real test function
      * 1. try to get the XMultiServiceFactory of an already running office. Therefore make sure an (open|star)office is running with
-     *    parameters like -accept="socket,host=localhost,port=8100;urp;"
+     *    parameters like --accept="socket,host=localhost,port=8100;urp;"
      * 2. try to create an empty window
      * 3. try to convert the WindowPeer to an XWindow
      * 4. try to resize and move the window to an other position, so we get a well knowing position and size.
diff --git a/vcl/qa/complex/memCheck/makefile.mk b/vcl/qa/complex/memCheck/makefile.mk
index 4a809e7..a880083 100755
--- a/vcl/qa/complex/memCheck/makefile.mk
+++ b/vcl/qa/complex/memCheck/makefile.mk
@@ -96,7 +96,7 @@ ALLTAR : javatest
 # CT_APPEXECCOMMAND =
 # .ELSE
 # CT_APPEXECCOMMAND = -AppExecutionCommand \
-#             "$(OFFICE)$/soffice -accept=socket,host=localhost,port=8100;urp;"
+#             "$(OFFICE)$/soffice --accept=socket,host=localhost,port=8100;urp;"
 # .ENDIF
 # 
 # # test base is java complex
diff --git a/writerfilter/qa/complex/ooxml/makefile.mk b/writerfilter/qa/complex/ooxml/makefile.mk
index 77df9fe..b4088b4 100644
--- a/writerfilter/qa/complex/ooxml/makefile.mk
+++ b/writerfilter/qa/complex/ooxml/makefile.mk
@@ -54,7 +54,7 @@ JARCOMPRESS     = TRUE
 .IF "$(OFFICE)" == ""
 CT_APPEXECCOMMAND =
 .ELSE
-CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice -accept=socket,host=localhost,port=8100;urp;"
+CT_APPEXECCOMMAND = -AppExecutionCommand "$(OFFICE)$/soffice --accept=socket,host=localhost,port=8100;urp;"
 .ENDIF
 
 # test base is java complex
diff --git a/xmlsecurity/tools/examples/evaluate_win.bat b/xmlsecurity/tools/examples/evaluate_win.bat
index 9567e9a..4a71a13 100644
--- a/xmlsecurity/tools/examples/evaluate_win.bat
+++ b/xmlsecurity/tools/examples/evaluate_win.bat
@@ -73,12 +73,12 @@ cp %WS_PATH%/xmlsecurity/wntmsci8.pro/bin/testtool.exe ./.
 
 @echo off
 echo =============================================
-echo step - 8 start OpenOffice
+echo step - 8 start LibreOffice
 echo =============================================
 @echo on
 
 @echo off
-echo please start up OpenOffice with "-accept=socket,host=0,port=2002;urp;"
+echo please start up LibreOffice with "--accept=socket,host=0,port=2002;urp;"
 pause Press Enter when finished...
 @echo on
 
@@ -105,12 +105,12 @@ testtool %WS_PATH%/xmlsecurity/tools/cryptoken/jks/testToken.jks %WS_PATH%/xmlse
 
 @echo off
 echo =============================================
-echo step - 10 stop OpenOffice
+echo step - 10 stop LibreOffice
 echo =============================================
 @echo on
 
 @echo off
-echo please stop the OpenOffice application
+echo please stop the LibreOffice application
 pause Press Enter when finished...
 @echo on
 
diff --git a/xmlsecurity/tools/examples/uno_win.bat b/xmlsecurity/tools/examples/uno_win.bat
index 6d1f74a..119ba7e 100644
--- a/xmlsecurity/tools/examples/uno_win.bat
+++ b/xmlsecurity/tools/examples/uno_win.bat
@@ -2,12 +2,12 @@ call env_win.bat
 
 @echo off
 echo =============================================
-echo step - 1 start OpenOffice
+echo step - 1 start LibreOffice
 echo =============================================
 @echo on
 
 @echo off
-echo please start up OpenOffice with "-accept=socket,host=0,port=2002;urp;"
+echo please start up LibreOffice with "--accept=socket,host=0,port=2002;urp;"
 pause Press Enter when finished...
 @echo on
 


More information about the Libreoffice-commits mailing list
diff --git a/toolkit/test/accessibility/OfficeConnection.java b/toolkit/test/accessibility/OfficeConnection.java
index 4cc5bee..9f2f3f5 100755
--- a/toolkit/test/accessibility/OfficeConnection.java
+++ b/toolkit/test/accessibility/OfficeConnection.java
@@ -14,7 +14,7 @@ import com.sun.star.uno.XInterface;
 import com.sun.star.uno.RuntimeException;
 
 
 /** @descr  This class establishes a connection to a StarOffice application.
  */
 public class OfficeConnection
 {
@@ -25,7 +25,7 @@ public class OfficeConnection
     }
 
     /** @descr Return the service manager that represents the connected
-                StarOffice application
+                LibreOffice application
     */
     public XMultiServiceFactory getServiceManager ()
     {
@@ -42,7 +42,7 @@ public class OfficeConnection
         return getServiceManager() != null;
     }
 
     /** @descr  Connect to a already running StarOffice application.
     */
     private void connect ()
     {
@@ -54,10 +54,10 @@ public class OfficeConnection
         connect (hostname, mnDefaultPort);
     }
 
     /** @descr  Connect to a already running StarOffice application that has
                 been started with a command line argument like
-                "-accept=socket,host=localhost,port=5678;urp;"
-    */
+		"--accept=socket,host=localhost,port=5678;urp;"
+		*/
     private void connect (String hostname, int portnumber)
     {
         mbInitialized = true;
@@ -86,8 +86,8 @@ public class OfficeConnection
         catch (Exception e)
         {
             MessageArea.println ("Could not connect with " + sConnectString + " : " + e);
-            MessageArea.println ("Please start OpenOffice/StarOffice with "
-                + "\"-accept=socket,host=localhost,port=5678;urp;\"");
+            MessageArea.println ("Please start LibreOffice with "
+                + "\"--accept=socket,host=localhost,port=5678;urp;\"");
         }
     }
 
@@ -14,7 +14,7 @@ import com.sun.star.uno.XInterface;
 
 
-/** @descr  This class establishes a connection to a StarOffice application.
+/** @descr  This class establishes a connection to a LibreOffice application.
  */
 public class OfficeConnection
@@ -42,7 +42,7 @@ public class OfficeConnection
     }
 
-    /** @descr  Connect to a already running StarOffice application.
+    /** @descr  Connect to an already running LibreOffice application.
     */
     private void connect ()
@@ -54,10 +54,10 @@ public class OfficeConnection
     }
 
-    /** @descr  Connect to a already running StarOffice application that has
+    /** @descr  Connect to a already running LibreOffice application that has
                 been started with a command line argument like